import { useCallback, useContext, useEffect, useMemo, useState } from "react";
import { defaultUser, defaultUserRoles } from "../stories/utils/common-args";
import { userContext } from "@ess-ics/ce-ui-common";

const testAuthContext = userContext;

const defaultLogin = "";
const defaultLogout = "";
const defaultLoginError = "";

const TestAuthContextProvider = ({ children }) => {
  const [user, setUser] = useState(defaultUser);
  const [userRoles, setUserRoles] = useState(defaultUserRoles);
  const [login, setLogin] = useState(defaultLogin);
  const [loginError, setLoginError] = useState(defaultLoginError);
  const [logout, setLogout] = useState(defaultLogout);

  const resetLoginError = useCallback(() => {
    setLoginError(defaultLoginError);
  }, [setLoginError]);

  const value = useMemo(
    () => ({
      user,
      setUser,
      userRoles,
      setUserRoles,
      login,
      setLogin,
      loginError,
      setLoginError,
      logout,
      setLogout,
      resetLoginError
    }),
    [
      user,
      setUser,
      userRoles,
      setUserRoles,
      login,
      setLogin,
      loginError,
      setLoginError,
      logout,
      setLogout,
      resetLoginError
    ]
  );

  return (
    <testAuthContext.Provider value={value}>
      {children}
    </testAuthContext.Provider>
  );
};

export const TestUserProvider = ({ children }) => {
  return <TestAuthContextProvider>{children}</TestAuthContextProvider>;
};

export const UserImpersonator = ({ user, userRoles, children }) => {
  const { setUser, setUserRoles } = useContext(testAuthContext);

  useEffect(() => {
    setUser(user);
    setUserRoles(userRoles);
  }, [setUser, setUserRoles, user, userRoles]);

  return <>{children}</>;
};
